(function webpackUniversalModuleDefinition(root, factory) {
	if(typeof exports === 'object' && typeof module === 'object')
		module.exports = factory(require("vue"), require("@kq_npm/client_common_vue/_utils/gis-utils"), require("@kq_npm/client_common_vue/_utils/util"), require("@kq_npm/client_common_vue/init.js"));
	else if(typeof define === 'function' && define.amd)
		define("@kq_npm/client3d_webgl_vue", ["vue", "@kq_npm/client_common_vue/_utils/gis-utils", "@kq_npm/client_common_vue/_utils/util", "@kq_npm/client_common_vue/init.js"], factory);
	else if(typeof exports === 'object')
		exports["@kq_npm/client3d_webgl_vue"] = factory(require("vue"), require("@kq_npm/client_common_vue/_utils/gis-utils"), require("@kq_npm/client_common_vue/_utils/util"), require("@kq_npm/client_common_vue/init.js"));
	else
		root["@kq_npm/client3d_webgl_vue"] = factory(root["Vue"], root["@kq_npm/client_common_vue/_utils/gis-utils"], root["@kq_npm/client_common_vue/_utils/util"], root["@kq_npm/client_common_vue/init.js"]);
})(this, function(__WEBPACK_EXTERNAL_MODULE__1895__, __WEBPACK_EXTERNAL_MODULE__7135__, __WEBPACK_EXTERNAL_MODULE__3458__, __WEBPACK_EXTERNAL_MODULE__7997__) {
return /******/ (function() { // webpackBootstrap
/******/ 	"use strict";
/******/ 	var __webpack_modules__ = ({

/***/ 2573:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ LightViewModel; }
/* harmony export */ });
/*
 * Copyright (C) 2019 KQ GEO Technologies Co., Ltd.
 * All rights reserved.
 */
//灯光特效逻辑类
class LightViewModel {
  _viewer = null;
  _light = null; //灯光对象
  _lightModel = null; // 灯光模型对象
  _lightModelDs = null; // 灯光模型集合
  _drawManager = null; //绘制管理对象
  _removeEventListener = null; //绘制完成监听事件
  _options = null; //灯光存储参数对象
  _lightList = []; //灯光对象集合

  constructor(scenceView, options) {
    this._options = options;
    this._viewer = scenceView._viewer;
    this._drawManager = scenceView._drawManager;
    this._drawHandler = this._drawManager._drawHandler.drawHandler;
    this._lightModelDs = new Cesium.CustomDataSource("LightModel");

    this._viewer.dataSources.add(this._lightModelDs);
    var that = this;
    that._removeEventListener = that._drawManager.drawFinishedEvent.addEventListener(shape => {
      if (shape && shape.type === "marker") {
        that._drawManager.clear();
        let position = shape.position;
        if (position) {
          if (that._options.mode == "point") {
            that.addPointLight(position);
          } else if (that._options.mode == "spot") {
            that.addSpotLight(position);
          }
        }
      }
    });
    that._handler = new Cesium.ScreenSpaceEventHandler(this._viewer.scene.canvas);
    that._handler.setInputAction(function () {
      if (that._drawHandler._shapeObject && that._drawHandler._shapeObject.type === "polyline") {
        let positions = that._drawHandler._shapeObject.controlPoints;
        if (positions.length === 3) {
          that._drawManager.stopDraw();
          if (that._options.mode == "parallel") {
            that.addParallelLight(positions[0], positions[1]);
          }
        }
      }
    }, Cesium.ScreenSpaceEventType.LEFT_CLICK);
  }
  //添加灯光
  addLight() {
    if (this._options) {
      if (this._options.mode == "point" || this._options.mode == "spot") {
        this._drawManager.startDraw("marker", { image: null });
      } else if (this._options.mode == "parallel") {
        this._drawManager.startDraw("polyline", { clampToGround: false });
      }
    }
  }
  //添加点光源
  addPointLight(position) {
    let color = Cesium.Color.fromCssColorString(this._options.color);
    if (Cesium.SplitDirection) {
      this._light = new Cesium.Kq3dPointLight({
        position: position,
        showPoint: false,
        color: color,
        cutoffDistance: this._options.distance,
        decay: this._options.decay,
        lightIntensity: this._options.intensity
      });
      this._viewer.scene.kq3dLightManager.add(this._light);
    } else if (Cesium.ImagerySplitDirection) {
      this._light = new Cesium.Kq3dPointLight({
        viewer: this._drawManager._viewer,
        pointPosition: position,
        showPoint: false,
        color: color,
        cutoffDistance: this._options.distance,
        decay: this._options.decay,
        lightIntensity: this._options.intensity
      });
    }
    this._lightModel = this._lightModelDs.entities.add({
      show: this._options.showModel,
      position: position,
      ellipsoid: {
        radii: new Cesium.Cartesian3(0.3, 0.3, 0.3),
        fill: true,
        material: color
      }
    });
    this._lightList.push(this._light);
  }
  //添加聚光灯
  addSpotLight(position) {
    let color = Cesium.Color.fromCssColorString(this._options.color);
    let lights = [{
      modelMatrix: Cesium.Transforms.eastNorthUpToFixedFrame(position),
      offset: new Cesium.Cartesian3(),
      direction: new Cesium.Cartesian3(0, 0, -1.0)
    }];
    if (Cesium.SplitDirection) {
      this._light = new Cesium.Kq3dSpotLightStage({
        viewer: this._viewer,
        lights: lights,
        color: color,
        angle: this._options.angle,
        cutoffDistance: this._options.distance,
        decay: this._options.decay,
        lightIntensity: this._options.intensity
      });
    } else if (Cesium.ImagerySplitDirection) {
      this._light = new Cesium.Kq3dSpotLight({
        viewer: this._viewer,
        lights: lights,
        color: color,
        angle: this._options.angle,
        cutoffDistance: this._options.distance,
        decay: this._options.decay,
        lightIntensity: this._options.intensity
      });
    }
    this._viewer.effects.add(this._light);
    this._lightList.push(this._light);
    this._lightModel = this._lightModelDs.entities.add({
      show: this._options.showModel,
      position: position,
      ellipsoid: {
        radii: new Cesium.Cartesian3(0.3, 0.3, 0.3),
        fill: true,
        material: color
      }
    });
  }
  //添加平行光
  addParallelLight(positionA, positionB) {
    let color = Cesium.Color.fromCssColorString(this._options.color);
    let direction = Cesium.Cartesian3.normalize(Cesium.Cartesian3.subtract(positionB, positionA, new Cesium.Cartesian3()),
      new Cesium.Cartesian3());
    this._light = new Cesium.DirectionalLight({
      direction: direction,
      color: color,
      intensity: this._options.intensity
    });
    this._viewer.scene.light = this._light;
    // this._lightList.push(this._light);
    // this._lightModel = this._lightModelDs.entities.add({
    //   show: this._options.showModel,
    //   position: positionA,
    //   ellipsoid: {
    //     radii: new Cesium.Cartesian3(0.3, 0.3, 0.3),
    //     fill: true,
    //     material: color
    //   }
    // });
  }
  //清除
  clear() {
    this._drawManager.stopDraw();
    this._drawManager.clear();
    this._lightModelDs.entities.removeAll();
    this.clearLights();
    this._light = null;
    this._lightModel = null;
  }
  // 清除所有灯光
  clearLights() {
    this._lightList.forEach(light => {
      if (light._postProcessStage) {
        this._viewer.scene.postProcessStages.remove(light._postProcessStage);
      } else if (light) {
        this._viewer.scene.kq3dLightManager.remove(light);
      }
    }, this);
    this._lightList = [];
    // 清除平行光
    if (!(this._viewer.scene.light instanceof Cesium.SunLight)) {
      this._viewer.scene.light = new Cesium.SunLight();
    }
  }
  //销毁
  destroy() {
    this.clear();
    //移除监听事件
    this._removeEventListener && this._removeEventListener();
    this._removeEventListener = null;
    this._handler && this._handler.destroy();
  }
  //设置光源颜色
  setColor(color) {
    let cesiumColor = Cesium.Color.fromCssColorString(color);
    if (this._light) {
      this._light.color = cesiumColor;
    }
    // 设置光源模型颜色
    if (this._lightModel) {
      this._lightModel.ellipsoid.material = cesiumColor;
    }
  }
  //设置扩散距离
  setDistance(distance) {
    if (this._light) {
      if (Cesium.SplitDirection) {
        if(this._options.mode  === 'spot'){
          this._light.cutoffDistance = Number(distance);
        }else{
          this._light.distance = Number(distance);
        }
      } else if (Cesium.ImagerySplitDirection) {
        this._light.cutoffDistance = Number(distance);
      }
    }
  }
  //设置衰减因子
  setDecay(decay) {
    if (this._light) {
      this._light.decay = Number(decay);
    }
  }
  //设置光源强度
  setIntensity(intensity) {
    if (this._light) {
      if (this._options.mode == "parallel") {
        this._light.intensity = Number(intensity);
      } else {
        if (Cesium.SplitDirection) {
          this._light.intensity = Number(intensity);
        } else if (Cesium.ImagerySplitDirection) {
          this._light.lightIntensity = Number(intensity);
        }
      }
    }
  }
  //光源模型显隐控制
  showModel(isShow) {
    if (this._lightModel) {
      this._lightModel.show = isShow;
    }
    //this._lightModelDs.show = isShow;
  }
  // 设置聚光灯角度
  showAngle(angle) {
    if (this._light) {
      this._light.angle = Number(angle);
    }
  }
}


/***/ }),

/***/ 348:
/***/ (function(module) {

module.exports = require("@kq_npm/client_icons_vue");

/***/ }),

/***/ 7080:
/***/ (function(module) {

module.exports = require("vue-i18n/dist/vue-i18n.cjs.js");

/***/ }),

/***/ 7135:
/***/ (function(module) {

module.exports = __WEBPACK_EXTERNAL_MODULE__7135__;

/***/ }),

/***/ 3458:
/***/ (function(module) {

module.exports = __WEBPACK_EXTERNAL_MODULE__3458__;

/***/ }),

/***/ 7997:
/***/ (function(module) {

module.exports = __WEBPACK_EXTERNAL_MODULE__7997__;

/***/ }),

/***/ 1895:
/***/ (function(module) {

module.exports = __WEBPACK_EXTERNAL_MODULE__1895__;

/***/ })

/******/ 	});
/************************************************************************/
/******/ 	// The module cache
/******/ 	var __webpack_module_cache__ = {};
/******/ 	
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/ 		// Check if module is in cache
/******/ 		var cachedModule = __webpack_module_cache__[moduleId];
/******/ 		if (cachedModule !== undefined) {
/******/ 			return cachedModule.exports;
/******/ 		}
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = __webpack_module_cache__[moduleId] = {
/******/ 			// no module.id needed
/******/ 			// no module.loaded needed
/******/ 			exports: {}
/******/ 		};
/******/ 	
/******/ 		// Execute the module function
/******/ 		__webpack_modules__[moduleId](module, module.exports, __webpack_require__);
/******/ 	
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/ 	
/************************************************************************/
/******/ 	/* webpack/runtime/compat get default export */
/******/ 	!function() {
/******/ 		// getDefaultExport function for compatibility with non-harmony modules
/******/ 		__webpack_require__.n = function(module) {
/******/ 			var getter = module && module.__esModule ?
/******/ 				function() { return module['default']; } :
/******/ 				function() { return module; };
/******/ 			__webpack_require__.d(getter, { a: getter });
/******/ 			return getter;
/******/ 		};
/******/ 	}();
/******/ 	
/******/ 	/* webpack/runtime/define property getters */
/******/ 	!function() {
/******/ 		// define getter functions for harmony exports
/******/ 		__webpack_require__.d = function(exports, definition) {
/******/ 			for(var key in definition) {
/******/ 				if(__webpack_require__.o(definition, key) && !__webpack_require__.o(exports, key)) {
/******/ 					Object.defineProperty(exports, key, { enumerable: true, get: definition[key] });
/******/ 				}
/******/ 			}
/******/ 		};
/******/ 	}();
/******/ 	
/******/ 	/* webpack/runtime/hasOwnProperty shorthand */
/******/ 	!function() {
/******/ 		__webpack_require__.o = function(obj, prop) { return Object.prototype.hasOwnProperty.call(obj, prop); }
/******/ 	}();
/******/ 	
/******/ 	/* webpack/runtime/make namespace object */
/******/ 	!function() {
/******/ 		// define __esModule on exports
/******/ 		__webpack_require__.r = function(exports) {
/******/ 			if(typeof Symbol !== 'undefined' && Symbol.toStringTag) {
/******/ 				Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });
/******/ 			}
/******/ 			Object.defineProperty(exports, '__esModule', { value: true });
/******/ 		};
/******/ 	}();
/******/ 	
/************************************************************************/
var __webpack_exports__ = {};
// This entry need to be wrapped in an IIFE because it need to be isolated against other modules in the chunk.
!function() {
// ESM COMPAT FLAG
__webpack_require__.r(__webpack_exports__);

// EXPORTS
__webpack_require__.d(__webpack_exports__, {
  "LightViewModel": function() { return /* reexport */ LightViewModel/* default */.Z; },
  "default": function() { return /* reexport */ Light; }
});

// EXTERNAL MODULE: external {"root":"Vue","commonjs":"vue","commonjs2":"vue","amd":"vue"}
var external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_ = __webpack_require__(1895);
// EXTERNAL MODULE: external "@kq_npm/client_common_vue/_utils/gis-utils"
var gis_utils_ = __webpack_require__(7135);
// EXTERNAL MODULE: external "@kq_npm/client_icons_vue"
var client_icons_vue_ = __webpack_require__(348);
// EXTERNAL MODULE: ./src/webgl/light/LightViewModel.js
var LightViewModel = __webpack_require__(2573);
// EXTERNAL MODULE: external "@kq_npm/client_common_vue/_utils/util"
var util_ = __webpack_require__(3458);
// EXTERNAL MODULE: external "vue-i18n/dist/vue-i18n.cjs.js"
var vue_i18n_cjs_js_ = __webpack_require__(7080);
;// CONCATENATED MODULE: ./node_modules/vue-loader/dist/index.js??ruleSet[0].use[0]!./src/webgl/light/Light.vue?vue&type=script&setup=true&lang=js


const _hoisted_1 = { class: "kq3d-light-box" }
const _hoisted_2 = { class: "kq3d-light-footer" }

;







const __default__ = {
  name: "Kq3dLight"
};

/* harmony default export */ var Lightvue_type_script_setup_true_lang_js = (/*#__PURE__*/Object.assign(__default__, {
  props: {
  // 设置参数
  settingParams: { type: Object },
  // 是否显示阴影效果
  showShadow: {
    type: Boolean,
    default: true
  },
  /**
   * 例："center","topLeft","topRight","bottomLeft","bottomRight", "topCenter", "bottomCenter" {top:'16px',left:'16px'}, {top:16,left:16}
   */
  position: [String, Object],
  // 是否生成HeaderTemp
  showHeaderTemp: {
    type: Boolean,
    default: false
  },
  // 是否折叠HeaderTemp，showHeaderTemp为true时生效
  isCollapseHeaderTemp: {
    type: Boolean,
    default: false
  },
  // HeaderTemp标题
  headerTempTitle: {
    type: String
  },
  // HeaderTemp图标
  headerTempIcon: {
    type: [Object, String],
    default: client_icons_vue_.IconLighting
  },
  // HeaderTemp Title&Icon的位置
  isRight: {
    type: Boolean,
    default: true
  }
},
  setup(__props, { expose: __expose }) {

const props = __props;

const { proxy } = (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.getCurrentInstance)();
let currentLang = (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.ref)("");
let language = (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.ref)(proxy.$i18n.global.messages[proxy.$i18n.global.locale]["webgl"]);


// 获取组件传参


let formItem = (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.reactive)({
  collapseValue: (props.settingParams && props.settingParams.collapseValue) || ((props.settingParams && props.settingParams.collapseValue)==''? "":"setting"), // 默认展开属性设置
  mode: (props.settingParams && props.settingParams.mode) || "point",
  color: (props.settingParams && props.settingParams.color) || "#fff",
  distance: (props.settingParams && props.settingParams.distance) || 200,
  minDistance: (props.settingParams && props.settingParams.minDistance) || 1,
  maxDistance: (props.settingParams && props.settingParams.maxDistance) || 1000,
  decay: (props.settingParams && props.settingParams.decay) || 0.1,
  minDecay: (props.settingParams && props.settingParams.minDecay) || 0,
  maxDecay: (props.settingParams && props.settingParams.maxDecay) || 1,
  intensity: (props.settingParams && props.settingParams.intensity) || 5,
  minIntensity: (props.settingParams && props.settingParams.minIntensity) || 0,
  maxIntensity: (props.settingParams && props.settingParams.maxIntensity) || 20,
  angle: (props.settingParams && props.settingParams.angle) || 80,
  minAngle: (props.settingParams && props.settingParams.minAngle) || 0,
  maxAngle: (props.settingParams && props.settingParams.maxAngle) || 160,
  showModel: (props.settingParams && props.settingParams.showModel) || true
});

let viewModel = null;

// 组件容器Ref
let boxRef = (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.ref)(null);

// 生成组件默认header
let headerTemp = (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.ref)();
let headerTempRef = (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.ref)();

// 国际化
let { locale, messages } = (0,vue_i18n_cjs_js_.useI18n)();
let headerTempTitle = (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.ref)(null);
headerTempTitle.value = language.value.light;
(0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.watch)(
  () => locale.value,
  (newVal, oldVal) => {
    language.value = messages.value[newVal]["webgl"];
    headerTempTitle.value = language.value.light;
  }
);

(0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.onMounted)(() => {
  (0,util_.updatePosition)(boxRef.value, props);
  (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.watch)(
    () => props.position,
    (newVal, oldVal) => {
      (0,util_.updatePosition)(boxRef.value, props);
    }
  );

  watchCreateHeaderTemp();
  (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.watch)(
    () => props.showHeaderTemp,
    (newVal, oldVal) => {
      (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.nextTick)(() => {
        watchCreateHeaderTemp();
      });
    }
  );

  currentLang.value = proxy.$i18n.locale; // 获取当前语言
  gis_utils_.utils.getWebMap(null, scenceView => {
    if (scenceView) {
      viewModel = new LightViewModel/* default */.Z(scenceView, formItem);
    }
  });
});

/**
 * @description 监听header生成
 */
const watchCreateHeaderTemp = () => {
  if (props.showHeaderTemp) {
    // 生成headerTemp
    headerTemp.value = (0,util_.createHeaderTemp)(boxRef.value, (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.toRefs)(props), headerTempRef, headerTempTitle);
  }
};

function changeMode(mode) {
  if (formItem.mode !== mode) {
    formItem.mode = mode;
  }
}

function paramsChanged(key) {
  switch (key) {
    case "color":
      viewModel && viewModel.setColor(formItem.color);
      break;
    case "distance":
      viewModel && viewModel.setDistance(formItem.distance);
      break;
    case "decay":
      viewModel && viewModel.setDecay(formItem.decay);
      break;
    case "intensity":
      viewModel && viewModel.setIntensity(formItem.intensity);
      break;
    case "showModel":
      viewModel && viewModel.showModel(formItem.showModel);
      break;
    case "angle":
      viewModel && viewModel.showAngle(formItem.angle);
      break;
    default:
      break;
  }
}

function add() {
  viewModel && viewModel.addLight();
}

function clear() {
  viewModel && viewModel.clear();
}

// 销毁
(0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.onBeforeUnmount)(() => {
  viewModel && viewModel.destroy();
});

__expose({
  changeMode,
  paramsChanged,
  add,
  clear
});

return (_ctx, _cache) => {
  const _component_kq_button = (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.resolveComponent)("kq-button")
  const _component_kq_row = (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.resolveComponent)("kq-row")
  const _component_kq_color_picker = (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.resolveComponent)("kq-color-picker")
  const _component_kq_form_item = (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.resolveComponent)("kq-form-item")
  const _component_kq_slider = (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.resolveComponent)("kq-slider")
  const _component_kq_col = (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.resolveComponent)("kq-col")
  const _component_kq_input_number = (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.resolveComponent)("kq-input-number")
  const _component_kq_switch = (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.resolveComponent)("kq-switch")
  const _component_kq_form = (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.resolveComponent)("kq-form")
  const _component_kq_collapse_item = (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.resolveComponent)("kq-collapse-item")
  const _component_kq_collapse = (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.resolveComponent)("kq-collapse")

  return ((0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.openBlock)(), (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createElementBlock)("section", {
    class: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.normalizeClass)(["kq3d-light", { 'kq-box-shadow': __props.showShadow }]),
    ref_key: "boxRef",
    ref: boxRef
  }, [
    (__props.showHeaderTemp)
      ? ((0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.openBlock)(), (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createBlock)((0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.resolveDynamicComponent)((0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(headerTemp)), {
          key: 0,
          ref_key: "headerTempRef",
          ref: headerTempRef
        }, null, 512 /* NEED_PATCH */))
      : (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createCommentVNode)("v-if", true),
    (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createElementVNode)("div", _hoisted_1, [
      (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_row, {
        gutter: 20,
        class: "rowclass"
      }, {
        default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
          (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_button, {
            icon: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(client_icons_vue_.IconPointLightSource),
            class: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.normalizeClass)(['kq3d-light-btn', (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).mode === 'point' ? 'kq3d-light-btn_active' : '']),
            onClick: _cache[0] || (_cache[0] = $event => (changeMode('point'))),
            title: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(language).pointLightSource
          }, null, 8 /* PROPS */, ["icon", "class", "title"]),
          (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_button, {
            icon: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(client_icons_vue_.IconSpotlight),
            class: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.normalizeClass)(['kq3d-light-btn', (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).mode === 'spot' ? 'kq3d-light-btn_active' : '']),
            onClick: _cache[1] || (_cache[1] = $event => (changeMode('spot'))),
            title: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(language).spotlight
          }, null, 8 /* PROPS */, ["icon", "class", "title"]),
          (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_button, {
            icon: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(client_icons_vue_.IconParallelLight),
            class: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.normalizeClass)(['kq3d-light-btn', (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).mode === 'parallel' ? 'kq3d-light-btn_active' : '']),
            onClick: _cache[2] || (_cache[2] = $event => (changeMode('parallel'))),
            title: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(language).parallelLight
          }, null, 8 /* PROPS */, ["icon", "class", "title"])
        ]),
        _: 1 /* STABLE */
      }),
      (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_row, { class: "kq3d-light-tip" }, {
        default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
          (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createElementVNode)("p", null, (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.toDisplayString)((0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(language).lightTips), 1 /* TEXT */)
        ]),
        _: 1 /* STABLE */
      }),
      (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_collapse, {
        "model-value": (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).collapseValue,
        class: "kq3d-light-collapse"
      }, {
        default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
          (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_collapse_item, {
            title: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(language).analysisSettings,
            name: "setting"
          }, {
            default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
              (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_form, {
                "label-width": (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(currentLang) === 'zh' ? '110px' : '120px',
                "label-position": "left"
              }, {
                default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
                  (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_row, { class: "rowclass" }, {
                    default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
                      (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_form_item, {
                        label: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(language).lightColor
                      }, {
                        default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
                          (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_row, { style: {"display":"flex"} }, {
                            default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
                              (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_color_picker, {
                                modelValue: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).color,
                                "onUpdate:modelValue": _cache[3] || (_cache[3] = $event => (((0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).color) = $event)),
                                onChange: _cache[4] || (_cache[4] = $event => (paramsChanged('color')))
                              }, null, 8 /* PROPS */, ["modelValue"])
                            ]),
                            _: 1 /* STABLE */
                          })
                        ]),
                        _: 1 /* STABLE */
                      }, 8 /* PROPS */, ["label"])
                    ]),
                    _: 1 /* STABLE */
                  }),
                  (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withDirectives)((0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_row, { class: "rowclass" }, {
                    default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
                      (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_form_item, {
                        label: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(language).spreadDistance
                      }, {
                        default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
                          (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_row, { style: {"display":"flex"} }, {
                            default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
                              (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_col, { span: 16 }, {
                                default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
                                  (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_slider, {
                                    modelValue: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).distance,
                                    "onUpdate:modelValue": _cache[5] || (_cache[5] = $event => (((0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).distance) = $event)),
                                    step: 1,
                                    min: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).minDistance,
                                    max: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).maxDistance,
                                    onChange: _cache[6] || (_cache[6] = $event => (paramsChanged('distance')))
                                  }, null, 8 /* PROPS */, ["modelValue", "min", "max"])
                                ]),
                                _: 1 /* STABLE */
                              }),
                              (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_col, { span: 8 }, {
                                default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
                                  (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_input_number, {
                                    modelValue: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).distance,
                                    "onUpdate:modelValue": _cache[7] || (_cache[7] = $event => (((0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).distance) = $event)),
                                    step: 1,
                                    min: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).minDistance,
                                    max: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).maxDistance,
                                    "controls-position": "right",
                                    onChange: _cache[8] || (_cache[8] = $event => (paramsChanged('distance')))
                                  }, null, 8 /* PROPS */, ["modelValue", "min", "max"])
                                ]),
                                _: 1 /* STABLE */
                              })
                            ]),
                            _: 1 /* STABLE */
                          })
                        ]),
                        _: 1 /* STABLE */
                      }, 8 /* PROPS */, ["label"])
                    ]),
                    _: 1 /* STABLE */
                  }, 512 /* NEED_PATCH */), [
                    [external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.vShow, (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).mode === 'point' || (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).mode === 'spot']
                  ]),
                  (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withDirectives)((0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_row, { class: "rowclass" }, {
                    default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
                      (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_form_item, {
                        label: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(language).angle+'(°)'
                      }, {
                        default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
                          (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_row, { style: {"display":"flex"} }, {
                            default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
                              (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_col, { span: 16 }, {
                                default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
                                  (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_slider, {
                                    modelValue: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).angle,
                                    "onUpdate:modelValue": _cache[9] || (_cache[9] = $event => (((0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).angle) = $event)),
                                    step: 1,
                                    min: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).minAngle,
                                    max: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).maxAngle,
                                    onChange: _cache[10] || (_cache[10] = $event => (paramsChanged('angle')))
                                  }, null, 8 /* PROPS */, ["modelValue", "min", "max"])
                                ]),
                                _: 1 /* STABLE */
                              }),
                              (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_col, { span: 8 }, {
                                default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
                                  (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_input_number, {
                                    modelValue: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).angle,
                                    "onUpdate:modelValue": _cache[11] || (_cache[11] = $event => (((0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).angle) = $event)),
                                    step: 1,
                                    min: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).minAngle,
                                    max: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).maxAngle,
                                    "controls-position": "right",
                                    onChange: _cache[12] || (_cache[12] = $event => (paramsChanged('angle')))
                                  }, null, 8 /* PROPS */, ["modelValue", "min", "max"])
                                ]),
                                _: 1 /* STABLE */
                              })
                            ]),
                            _: 1 /* STABLE */
                          })
                        ]),
                        _: 1 /* STABLE */
                      }, 8 /* PROPS */, ["label"])
                    ]),
                    _: 1 /* STABLE */
                  }, 512 /* NEED_PATCH */), [
                    [external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.vShow, (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).mode === 'spot']
                  ]),
                  (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withDirectives)((0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_row, { class: "rowclass" }, {
                    default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
                      (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_form_item, {
                        label: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(language).decayFactor
                      }, {
                        default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
                          (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_row, { style: {"display":"flex"} }, {
                            default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
                              (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_col, { span: 16 }, {
                                default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
                                  (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_slider, {
                                    modelValue: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).decay,
                                    "onUpdate:modelValue": _cache[13] || (_cache[13] = $event => (((0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).decay) = $event)),
                                    step: 0.01,
                                    min: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).minDecay,
                                    max: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).maxDecay,
                                    onChange: _cache[14] || (_cache[14] = $event => (paramsChanged('decay')))
                                  }, null, 8 /* PROPS */, ["modelValue", "step", "min", "max"])
                                ]),
                                _: 1 /* STABLE */
                              }),
                              (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_col, { span: 8 }, {
                                default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
                                  (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_input_number, {
                                    modelValue: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).decay,
                                    "onUpdate:modelValue": _cache[15] || (_cache[15] = $event => (((0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).decay) = $event)),
                                    step: 0.01,
                                    min: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).minDecay,
                                    max: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).maxDecay,
                                    "controls-position": "right",
                                    onChange: _cache[16] || (_cache[16] = $event => (paramsChanged('decay')))
                                  }, null, 8 /* PROPS */, ["modelValue", "step", "min", "max"])
                                ]),
                                _: 1 /* STABLE */
                              })
                            ]),
                            _: 1 /* STABLE */
                          })
                        ]),
                        _: 1 /* STABLE */
                      }, 8 /* PROPS */, ["label"])
                    ]),
                    _: 1 /* STABLE */
                  }, 512 /* NEED_PATCH */), [
                    [external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.vShow, (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).mode === 'point' || (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).mode === 'spot']
                  ]),
                  (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_row, { class: "rowclass" }, {
                    default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
                      (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_form_item, {
                        label: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(language).lightStrength
                      }, {
                        default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
                          (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_row, { style: {"display":"flex"} }, {
                            default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
                              (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_col, { span: 16 }, {
                                default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
                                  (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_slider, {
                                    modelValue: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).intensity,
                                    "onUpdate:modelValue": _cache[17] || (_cache[17] = $event => (((0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).intensity) = $event)),
                                    step: 0.1,
                                    min: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).minIntensity,
                                    max: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).maxIntensity,
                                    onChange: _cache[18] || (_cache[18] = $event => (paramsChanged('intensity')))
                                  }, null, 8 /* PROPS */, ["modelValue", "step", "min", "max"])
                                ]),
                                _: 1 /* STABLE */
                              }),
                              (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_col, { span: 8 }, {
                                default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
                                  (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_input_number, {
                                    modelValue: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).intensity,
                                    "onUpdate:modelValue": _cache[19] || (_cache[19] = $event => (((0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).intensity) = $event)),
                                    step: 0.1,
                                    min: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).minIntensity,
                                    max: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).maxIntensity,
                                    "controls-position": "right",
                                    onChange: _cache[20] || (_cache[20] = $event => (paramsChanged('intensity')))
                                  }, null, 8 /* PROPS */, ["modelValue", "step", "min", "max"])
                                ]),
                                _: 1 /* STABLE */
                              })
                            ]),
                            _: 1 /* STABLE */
                          })
                        ]),
                        _: 1 /* STABLE */
                      }, 8 /* PROPS */, ["label"])
                    ]),
                    _: 1 /* STABLE */
                  }),
                  (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withDirectives)((0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_row, { class: "rowclass" }, {
                    default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
                      (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_form_item, {
                        label: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(language).lightModel
                      }, {
                        default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
                          (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_row, { style: {"display":"flex"} }, {
                            default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
                              (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_switch, {
                                modelValue: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).showModel,
                                "onUpdate:modelValue": _cache[21] || (_cache[21] = $event => (((0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).showModel) = $event)),
                                "controls-position": "left",
                                onChange: _cache[22] || (_cache[22] = $event => (paramsChanged('showModel')))
                              }, null, 8 /* PROPS */, ["modelValue"])
                            ]),
                            _: 1 /* STABLE */
                          })
                        ]),
                        _: 1 /* STABLE */
                      }, 8 /* PROPS */, ["label"])
                    ]),
                    _: 1 /* STABLE */
                  }, 512 /* NEED_PATCH */), [
                    [external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.vShow, (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).mode === 'point' || (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(formItem).mode === 'spot']
                  ])
                ]),
                _: 1 /* STABLE */
              }, 8 /* PROPS */, ["label-width"])
            ]),
            _: 1 /* STABLE */
          }, 8 /* PROPS */, ["title"])
        ]),
        _: 1 /* STABLE */
      }, 8 /* PROPS */, ["model-value"]),
      (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createElementVNode)("div", _hoisted_2, [
        (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_button, {
          onClick: _cache[23] || (_cache[23] = (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withModifiers)($event => (add()), ["stop"])),
          title: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(language).add,
          type: "primary"
        }, {
          default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
            (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createTextVNode)((0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.toDisplayString)((0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(language).add), 1 /* TEXT */)
          ]),
          _: 1 /* STABLE */
        }, 8 /* PROPS */, ["title"]),
        (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createVNode)(_component_kq_button, {
          onClick: _cache[24] || (_cache[24] = (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withModifiers)($event => (clear()), ["stop"])),
          title: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(language).clear
        }, {
          default: (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.withCtx)(() => [
            (0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.createTextVNode)((0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.toDisplayString)((0,external_root_Vue_commonjs_vue_commonjs2_vue_amd_vue_.unref)(language).clear), 1 /* TEXT */)
          ]),
          _: 1 /* STABLE */
        }, 8 /* PROPS */, ["title"])
      ])
    ])
  ], 2 /* CLASS */))
}
}

}));
;// CONCATENATED MODULE: ./src/webgl/light/Light.vue?vue&type=script&setup=true&lang=js
 
;// CONCATENATED MODULE: ./src/webgl/light/Light.vue



const __exports__ = Lightvue_type_script_setup_true_lang_js;

/* harmony default export */ var Light = (__exports__);
// EXTERNAL MODULE: external "@kq_npm/client_common_vue/init.js"
var init_js_ = __webpack_require__(7997);
var init_js_default = /*#__PURE__*/__webpack_require__.n(init_js_);
;// CONCATENATED MODULE: ./src/webgl/light/index.js
/*
 * Copyright (C) 2019 KQ GEO Technologies Co., Ltd.
 * All rights reserved.
 */




Light.install = (Vue, opts) => {
  init_js_default()(Vue, opts);
  Vue.component(Light.name, Light);
};



}();
/******/ 	return __webpack_exports__;
/******/ })()
;
});